==> buildpack-client-0.0.6-sources.jar: dev/snowdrop/buildpack/docker/StringContentBuilder.java <==
package dev.snowdrop.buildpack.docker;

import dev.snowdrop.buildpack.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
public class StringContentBuilder extends dev.snowdrop.buildpack.docker.StringContentFluentImpl<dev.snowdrop.buildpack.docker.StringContentBuilder> implements dev.snowdrop.buildpack.builder.VisitableBuilder<dev.snowdrop.buildpack.docker.StringContent,dev.snowdrop.buildpack.docker.StringContentBuilder>{
  public StringContentBuilder() {
    this(false);
  }
  public StringContentBuilder(java.lang.Boolean validationEnabled) {
    this.fluent = this; this.validationEnabled=validationEnabled;
  }
  public StringContentBuilder(dev.snowdrop.buildpack.docker.StringContentFluent<?> fluent) {
    this(fluent, false);
  }
  public StringContentBuilder(dev.snowdrop.buildpack.docker.StringContentFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; this.validationEnabled=validationEnabled;
  }
  public StringContentBuilder(dev.snowdrop.buildpack.docker.StringContentFluent<?> fluent,dev.snowdrop.buildpack.docker.StringContent instance) {
    this(fluent, instance, false);
  }
  public StringContentBuilder(dev.snowdrop.buildpack.docker.StringContentFluent<?> fluent,dev.snowdrop.buildpack.docker.StringContent instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withPath(instance.getPath()); 
    fluent.withContent(instance.getContent()); 
    this.validationEnabled = validationEnabled; 
  }
  public StringContentBuilder(dev.snowdrop.buildpack.docker.StringContent instance) {
    this(instance,false);
  }
  public StringContentBuilder(dev.snowdrop.buildpack.docker.StringContent instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withPath(instance.getPath()); 
    this.withContent(instance.getContent()); 
    this.validationEnabled = validationEnabled; 
  }
  dev.snowdrop.buildpack.docker.StringContentFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public dev.snowdrop.buildpack.docker.EditableStringContent build() {
    EditableStringContent buildable = new EditableStringContent(fluent.getPath(),fluent.getContent());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    StringContentBuilder that = (StringContentBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> buildpack-client-0.0.14-sources.jar: dev/snowdrop/buildpack/docker/StringContentBuilder.java <==
package dev.snowdrop.buildpack.docker;

import dev.snowdrop.buildpack.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
public class StringContentBuilder extends dev.snowdrop.buildpack.docker.StringContentFluentImpl<dev.snowdrop.buildpack.docker.StringContentBuilder> implements dev.snowdrop.buildpack.builder.VisitableBuilder<dev.snowdrop.buildpack.docker.StringContent,dev.snowdrop.buildpack.docker.StringContentBuilder>{
  public StringContentBuilder() {
    this(false);
  }
  public StringContentBuilder(java.lang.Boolean validationEnabled) {
    this.fluent = this; this.validationEnabled=validationEnabled;
  }
  public StringContentBuilder(dev.snowdrop.buildpack.docker.StringContentFluent<?> fluent) {
    this(fluent, false);
  }
  public StringContentBuilder(dev.snowdrop.buildpack.docker.StringContentFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; this.validationEnabled=validationEnabled;
  }
  public StringContentBuilder(dev.snowdrop.buildpack.docker.StringContentFluent<?> fluent,dev.snowdrop.buildpack.docker.StringContent instance) {
    this(fluent, instance, false);
  }
  public StringContentBuilder(dev.snowdrop.buildpack.docker.StringContentFluent<?> fluent,dev.snowdrop.buildpack.docker.StringContent instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withPath(instance.getPath()); 
    fluent.withContent(instance.getContent()); 
    this.validationEnabled = validationEnabled; 
  }
  public StringContentBuilder(dev.snowdrop.buildpack.docker.StringContent instance) {
    this(instance,false);
  }
  public StringContentBuilder(dev.snowdrop.buildpack.docker.StringContent instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withPath(instance.getPath()); 
    this.withContent(instance.getContent()); 
    this.validationEnabled = validationEnabled; 
  }
  dev.snowdrop.buildpack.docker.StringContentFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public dev.snowdrop.buildpack.docker.EditableStringContent build() {
    EditableStringContent buildable = new EditableStringContent(fluent.getPath(),fluent.getMode(),fluent.getContent());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    StringContentBuilder that = (StringContentBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
